sqlite3_web library

Classes

ClientConnection
A connection from a client from the perspective of a worker.
ConnectToRecommendedResult
The result of WebSqlite.connectToRecommended, containing the opened database as well as the FeatureDetectionResult leading to that database implementation being chosen.
CustomClientDatabaseRequest
A CustomClientRequest sent to a worker-managed database
CustomClientRequest
A custom request sent from a client to a worker hosting a database.
Database
Abstraction over a database either available locally or in a remote worker.
DatabaseController
A controller responsible for opening databases in the worker.
FakeWorkerEnvironment
A worker environment that isn't in an actual web worker.
FeatureDetectionResult
The result of WebSqlite.runFeatureDetection, describing which browsers and databases are available in the current browser.
FileSystem
A virtual file system used by a worker to persist database files.
WebSqlite
Provides asynchronous access to databases hosted in web workers.
WorkerConnector
An interface abstracting over Worker and SharedWorker constructors, allowing clients of sqlite3_web to customize if and how workers are used.
WorkerDatabase
A CommonDatabase wrapped with functionality to handle custom requests.
WorkerEnvironment
Environment for workers hosting SQLite databases.
WorkerHandle
Handle to a shared or dedicated web worker.

Enums

AccessMode
In addition to the StorageMode describing which browser API is used to store content, this enum describes how databases are accessed.
DatabaseImplementation
An implemented mechanism to use SQLite on the web.
FileType
Types of files persisted for databases by virtual file system implementations.
MissingBrowserFeature
An enumeration of features not supported by the current browsers.
StorageMode
Available locations to store database content in browsers.

Extension Types

LockToken
Database.requestLock.

Typedefs

DatabaseResult<T> = ({bool autocommit, int lastInsertRowid, T result})
ExistingDatabase = (StorageMode, String)
A StorageMode, name pair representing an existing database already stored by the current browsing context.
SqliteWebEndpoint = (MessagePort, String)
An endpoint that can be used, by any running JavaScript context in the same website, to connect to an existing Database.

Exceptions / Errors

AbortException
An exception thrown when the remote end accepts an abort requeset sent for a previous request.
ChannelClosedException
An exception thrown when a request is sent over a closed channel to a worker.
RemoteException
An exception thrown when a operation fails on the remote worker.