types library
Cross-platform types related to the sqlite3_web package.
This library can safely be imported both when targeting the web and when compiling to native targets. Using these types may be convenient for shared options.
Classes
- FeatureDetectionResult
- The result of WebSqlite.runFeatureDetection, describing which browsers and databases are available in the current browser.
- FileSystem
- A virtual file system used by a worker to persist database files.
Enums
- AccessMode
- In addition to the StorageMode describing which browser API is used to store content, this enum describes how databases are accessed.
- DatabaseImplementation
- An implemented mechanism to use SQLite on the web.
- FileType
- Types of files persisted for databases by virtual file system implementations.
- MissingBrowserFeature
- An enumeration of features not supported by the current browsers.
- StorageMode
- Available locations to store database content in browsers.
Typedefs
- ExistingDatabase = (StorageMode, String)
- A StorageMode, name pair representing an existing database already stored by the current browsing context.
Exceptions / Errors
- AbortException
- An exception thrown when the remote end accepts an abort requeset sent for a previous request.
- RemoteException
- An exception thrown when a operation fails on the remote worker.