CustomClientRequest class final
A custom request sent from a client to a worker hosting a database.
- Implementers
Constructors
- CustomClientRequest({required JSAny? request, required AbortSignal abortSignal})
Properties
- abortSignal → AbortSignal
-
A signal allowing clients to abort this request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → JSAny?
-
The custom message sent from the client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited